gnucash maint: Bug 797898 - [reconciliation] calculated balance amount per...

John Ralls jralls at code.gnucash.org
Tue Sep 22 16:46:31 EDT 2020


Updated	 via  https://github.com/Gnucash/gnucash/commit/a926991d (commit)
	from  https://github.com/Gnucash/gnucash/commit/3d93c7ed (commit)



commit a926991d75c2138d73aaef52ced232705c33e724
Author: John Ralls <jralls at ceridwen.us>
Date:   Tue Sep 22 13:43:35 2020 -0700

    Bug 797898 - [reconciliation] calculated balance amount per...
    
    reconcilation date depending on actual time.
    
    Set the statement date that's really a time to the end of the day
    so that transactions posted on the day are always included.

diff --git a/gnucash/gnome/window-reconcile.c b/gnucash/gnome/window-reconcile.c
index 1eec32158..e08913f37 100644
--- a/gnucash/gnome/window-reconcile.c
+++ b/gnucash/gnome/window-reconcile.c
@@ -1663,13 +1663,15 @@ recnWindow (GtkWidget *parent, Account *account)
     if (account == NULL)
         return NULL;
 
     /* The last time reconciliation was attempted during the current
      * execution of gnucash, the date was stored. Use that date if
      * possible. This helps with balancing multiple accounts for which
      * statements are issued at the same time, like multiple bank
      * accounts on a single statement. */
     if (!gnc_reconcile_last_statement_date)
-        statement_date = gnc_time (NULL);
+        statement_date = gnc_time64_get_day_end(gnc_time (NULL));
     else
         statement_date = gnc_reconcile_last_statement_date;
 
@@ -1663,13 +1663,15 @@ recnWindow (GtkWidget *parent, Account *account)
         return NULL;
 
-    /* The last time reconciliation was attempted during the current
-     * execution of gnucash, the date was stored. Use that date if
-     * possible. This helps with balancing multiple accounts for which
-     * statements are issued at the same time, like multiple bank
-     * accounts on a single statement. */
+    /* The last time reconciliation was attempted during the current execution
+     * of gnucash, the date was stored. Use that date if possible. This helps
+     * with balancing multiple accounts for which statements are issued at the
+     * same time, like multiple bank accounts on a single statement. Otherwise
+     * use the end of today to ensure we include any transactions posted
+     * today.
+     */
     if (!gnc_reconcile_last_statement_date)



Summary of changes:
 gnucash/gnome/window-reconcile.c | 14 ++++++++------
 1 file changed, 8 insertions(+), 6 deletions(-)



More information about the gnucash-changes mailing list